@@ -188,19 +188,16 @@ class R3sponse(object):
 				raise TypeError(f"You most likely returned a r3sponse.error_response when you meant a r3sponse.success_response, error: {e}")
 			else:
 				raise TypeError(e)
-		print("json 1:",json)
 		if comparison:
 			#print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
 			if json:
 				if response != {}:
 					print(response)
+				elif error != None:
+					print(self.error_response(error))
 				else:
-					print(self.response(response))
-			if json and response != {}:
-				print("json 2:",json)
-				print(response)
+					print(self.success_response(message))
 			else:
-				print("json 3:",json)
 				print(f"{color.fill(msg)}")
 		if save: 
 			self.__log_to_file__(msg)
